@@ -41,7 +41,7 @@ pub mod example {
     //! }
     //!
     //! macro_attr! {
-    //!     #[derive(ComponentId!, Debug, Copy, Clone, Eq, PartialEq, Hash, Ord, PartialOrd)]
+    //!     #[derive(NewtypeComponentId!, Debug, Copy, Clone, Eq, PartialEq, Hash, Ord, PartialOrd)]
     //!     pub struct MyDepTypeId(Id<MyDepTypePrivateData>);
     //! }
     //!
@@ -71,7 +71,7 @@ pub mod example {
     //! }
 
     use crate::{dep_obj, dep_type};
-    use components_arena::{Arena, Component, ComponentId, Id};
+    use components_arena::{Arena, Component, NewtypeComponentId, Id};
     use dyn_context::State;
 
     dep_type! {
@@ -92,7 +92,7 @@ pub mod example {
     #[derive(Debug, Copy, Clone, Eq, PartialEq, Hash, Ord, PartialOrd)]
     pub struct MyDepTypeId(Id<MyDepTypePrivateData>);
 
-    ComponentId!(() pub struct MyDepTypeId(Id<MyDepTypePrivateData>););
+    NewtypeComponentId!(() pub struct MyDepTypeId(Id<MyDepTypePrivateData>););
 
     #[derive(Debug)]
     pub struct MyApp {
@@ -146,6 +146,7 @@ pub use paste::paste as paste_paste;
 use crate::flow::{Flow, FlowSource, Just, Through, Snd, RemovedInserted};
 use alloc::boxed::Box;
 use alloc::collections::TryReserveError;
+use alloc::vec;
 use alloc::vec::Vec;
 use components_arena::{ComponentId, RawId};
 use core::fmt::Debug;
@@ -204,7 +205,7 @@ impl<ItemType: Convenient> DepVecEntry<ItemType> {
 /// # #![feature(const_maybe_uninit_as_ptr)]
 /// # #![feature(const_ptr_offset_from)]
 /// # #![feature(const_raw_ptr_deref)]
-/// use components_arena::{Arena, Component, ComponentClassToken, ComponentId, Id};
+/// use components_arena::{Arena, Component, ComponentClassToken, NewtypeComponentId, Id};
 /// use dep_obj::{dep_obj, dep_type};
 /// use dep_obj::flow::{Flows, FlowsToken, Just};
 /// use dyn_context::{State, StateExt};
@@ -227,7 +228,7 @@ impl<ItemType: Convenient> DepVecEntry<ItemType> {
 /// }
 ///
 /// macro_attr! {
-///     #[derive(ComponentId!, Debug, Copy, Clone, Eq, PartialEq, Hash, Ord, PartialOrd)]
+///     #[derive(NewtypeComponentId!, Debug, Copy, Clone, Eq, PartialEq, Hash, Ord, PartialOrd)]
 ///     pub struct MyDepTypeId(Id<MyDepTypePrivateData>);
 /// }
 ///
@@ -619,6 +620,18 @@ impl<'a, 'b, Owner: DepType, Arena: 'static, ItemType: Convenient> DepObjVec<'a,
         }
     }
 
+    pub fn remove(&mut self, index: usize) {
+        let arena: &mut Arena = self.obj.state.get_mut();
+        let obj = (self.obj.get_obj_mut)(arena, self.obj.id);
+        let entry_mut = self.vec.entry_mut(obj);
+        let item = entry_mut.items.remove(index);
+        let change = VecChange::Removed(index, vec![item]);
+        let vec = entry_mut.items.clone();
+        for (handler_id, handler) in entry_mut.on_changed.clone() {
+            handler(self.obj.state, handler_id, (change.clone(), vec.clone()));
+        }
+    }
+
     pub fn append(&mut self, other: &mut Vec<ItemType>) {
         let arena: &mut Arena = self.obj.state.get_mut();
         let obj = (self.obj.get_obj_mut)(arena, self.obj.id);
@@ -1157,7 +1170,7 @@ macro_rules! dep_type_impl_raw {
             [$($g)*] [$($r)*] [$($w)*]
             [
                 $($core_fields)*
-                $field: $crate::DepVecEntry<$Id, $field_ty>,
+                $field: $crate::DepVecEntry<$field_ty>,
             ]
             [
                 $($core_new)*
